@@ -1,7 +1,6 @@
-from typing import Any, Dict, List, Set
+from typing import Any, Dict, List
 from datetime import datetime
 from copy import copy
-import pytz
 
 from vnpy.event import EventEngine
 from vnpy.trader.event import EVENT_TIMER
@@ -26,7 +25,8 @@ from vnpy.trader.object import (
     PositionData,
     AccountData
 )
-from vnpy.trader.utility import get_folder_path
+from vnpy.trader.utility import get_folder_path, ZoneInfo
+
 from ..api import (
     MdApi,
     TdApi,
@@ -48,6 +48,7 @@ from ..api import (
     DFITCSEC_COMPRESS_FALSE
 )
 
+
 # 多空方向映射
 DIRECTION_VT2HTS: Dict[Direction, int] = {
     Direction.LONG: DFITCSEC_ED_Buy,
@@ -103,7 +104,7 @@ COMPRESS_VT2HTS: Dict[str, int] = {
 }
 
 # 其他常量
-CHINA_TZ = pytz.timezone("Asia/Shanghai")       # 中国时区
+CHINA_TZ = ZoneInfo("Asia/Shanghai")       # 中国时区
 
 # 合约数据全局缓存字典
 symbol_contract_map: Dict[str, ContractData] = {}
@@ -255,14 +256,14 @@ class HtsMdApi(MdApi):
         self.collection_type: int = 1
 
         self.reqid: int = 0
-        self.subscribed: Set = set()
+        self.subscribed: set = set()
 
         self.sse_inited: bool = False
         self.szse_inited: bool = False
 
     def onFrontConnected(self) -> None:
         """服务器连接成功回报"""
-        self.gateway.write_log(f"行情服务器连接成功")
+        self.gateway.write_log("行情服务器连接成功")
         self.connect_status = True
 
         self.login_server()
@@ -296,7 +297,7 @@ class HtsMdApi(MdApi):
         """行情数据推送"""
         timestamp: str = str(data["tradingDay"]) + str(data["updateTime"])
         dt: datetime = datetime.strptime(timestamp, "%Y%m%d%H:%M:%S.%f")
-        dt: datetime = CHINA_TZ.localize(dt)
+        dt: datetime = dt.replace(tzinfo=CHINA_TZ)
 
         tick: TickData = TickData(
             symbol=data["securityID"],
@@ -336,7 +337,7 @@ class HtsMdApi(MdApi):
         tick.ask_volume_4 = data["askQty4"]
         tick.ask_volume_5 = data["askQty5"]
 
-        contract = symbol_contract_map.get(tick.symbol, None)
+        contract: ContractData = symbol_contract_map.get(tick.symbol, None)
         if contract:
             tick.name = contract.name
 
@@ -412,7 +413,7 @@ class HtsTdApi(TdApi):
         self.auth_code: str = ""
         self.app_id: str = ""
         self.collection_type: int = 1
-        self.positions: dict = {}
+        self.positions: Dict[str, PositionData] = {}
 
         self.sessionid: str = ""
         self.reqid: int = 0
@@ -424,7 +425,7 @@ class HtsTdApi(TdApi):
 
     def onFrontConnected(self) -> None:
         """服务器连接成功回报"""
-        self.gateway.write_log(f"交易服务器连接成功")
+        self.gateway.write_log("交易服务器连接成功")
         self.connect_status = True
 
         self.login_server()
@@ -440,7 +441,7 @@ class HtsTdApi(TdApi):
         if not error:
             self.sessionid = str(data["sessionID"])
 
-            self.gateway.write_log(f"股票期权交易服务器登录成功")
+            self.gateway.write_log("股票期权交易服务器登录成功")
             self.login_status = True
 
             self.query_option_contracts("")
@@ -459,7 +460,7 @@ class HtsTdApi(TdApi):
 
         timestamp: str = str(datetime.date(datetime.now())) + str(data["entrustTime"])
         dt: datetime = datetime.strptime(timestamp, "%Y-%m-%d%H:%M:%S.%f")
-        dt: datetime = CHINA_TZ.localize(dt)
+        dt: datetime = dt.replace(tzinfo=CHINA_TZ)
 
         if orderid in self.orders:
             order: OrderData = self.orders[orderid]
@@ -491,7 +492,7 @@ class HtsTdApi(TdApi):
         """成交数据推送"""
         timestamp: str = str(datetime.date(datetime.now())) + str(data["tradeTime"])
         dt: datetime = datetime.strptime(timestamp, "%Y-%m-%d%H:%M:%S.%f")
-        dt: datetime = CHINA_TZ.localize(dt)
+        dt: datetime = dt.replace(tzinfo=CHINA_TZ)
         localid: str = str(data["localOrderID"])
         sessionid: str = str(data["sessionID"])
         orderid: str = f"{sessionid}_{localid}"
@@ -578,7 +579,7 @@ class HtsTdApi(TdApi):
 
             if order:
                 dt: datetime = datetime.now()
-                dt: datetime = CHINA_TZ.localize(dt)
+                dt: datetime = dt.replace(tzinfo=CHINA_TZ)
                 order.datetime = dt
                 order.status = Status.REJECTED
                 self.gateway.on_order(copy(order))
@@ -651,7 +652,7 @@ class HtsTdApi(TdApi):
         )
         self.gateway.on_position(pos)
 
-        pos_symbol = f"{data['securityOptionID']}_{data['entrustDirection']}"
+        pos_symbol: str = f"{data['securityOptionID']}_{data['entrustDirection']}"
         self.positions[pos_symbol] = pos
 
     def connect(
@@ -745,7 +746,7 @@ class HtsTdApi(TdApi):
         self.reqSOPQryCapitalAccountInfo(req)
 
     def query_position(self) -> None:
-        """"""
+        """查询持仓"""
         self.reqid += 1
         req: dict = {
             "requestID": self.reqid,
@@ -754,7 +755,7 @@ class HtsTdApi(TdApi):
         self.reqSOPQryPosition(req)
 
     def query_option_contracts(self, index: str) -> None:
-        """"""
+        """查询合约"""
         self.reqid += 1
         req: dict = {
             "requestID": self.reqid,
@@ -771,18 +772,18 @@ class HtsTdApi(TdApi):
 
 def get_option_index(strike_price: float, exchange_instrument_id: str) -> str:
     """获取期权索引"""
-    exchange_instrument_id = exchange_instrument_id.replace(" ", "")
+    exchange_instrument_id: str = exchange_instrument_id.replace(" ", "")
 
     if "M" in exchange_instrument_id:
-        n = exchange_instrument_id.index("M")
+        n: int = exchange_instrument_id.index("M")
     elif "A" in exchange_instrument_id:
-        n = exchange_instrument_id.index("A")
+        n: int = exchange_instrument_id.index("A")
     elif "B" in exchange_instrument_id:
-        n = exchange_instrument_id.index("B")
+        n: int = exchange_instrument_id.index("B")
     else:
         return str(strike_price)
 
-    index = exchange_instrument_id[n:]
-    option_index = f"{strike_price:.3f}-{index}"
+    index: str = exchange_instrument_id[n:]
+    option_index: str = f"{strike_price:.3f}-{index}"
 
     return option_index
